==> xcsoar-6.5.1.tar.bz2: xcsoar-6.5.1/src/Engine/Task/Factory/TouringTaskFactory.cpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
 */

#include "TouringTaskFactory.hpp"
#include "TaskFactoryConstraints.hpp"
#include "Task/Ordered/OrderedTaskBehaviour.hpp"
#include "Util/Macros.hpp"

static constexpr TaskFactoryConstraints touring_constraints = {
  false,
  false,
  true,
  false,
  false,
  2, 10,
};

static constexpr TaskPointFactoryType touring_start_types[] = {
  TaskPointFactoryType::START_CYLINDER,
};

static constexpr TaskPointFactoryType touring_im_types[] = {
  TaskPointFactoryType::FAI_SECTOR,
};

static constexpr TaskPointFactoryType touring_finish_types[] = {
  TaskPointFactoryType::FINISH_CYLINDER,
};

TouringTaskFactory::TouringTaskFactory(OrderedTask& _task,
                               const TaskBehaviour &tb)
  :AbstractTaskFactory(touring_constraints, _task, tb,
                       LegalPointConstArray(touring_start_types,
                                            ARRAY_SIZE(touring_start_types)),
                       LegalPointConstArray(touring_im_types,
                                            ARRAY_SIZE(touring_im_types)),
                       LegalPointConstArray(touring_finish_types,
                                            ARRAY_SIZE(touring_finish_types)))
{
}

void 
TouringTaskFactory::UpdateOrderedTaskBehaviour(OrderedTaskBehaviour& to)
{
  AbstractTaskFactory::UpdateOrderedTaskBehaviour(to);

  to.aat_min_time = fixed(0);

  to.start_constraints.max_speed = fixed(0);
  to.start_constraints.max_height = 0;
  to.start_constraints.max_height_ref = AltitudeReference::AGL;
  to.finish_constraints.min_height = 0;
}

==> xcsoar-6.6.1.tar.bz2: xcsoar-6.6.1/src/Engine/Task/Factory/TouringTaskFactory.cpp <==
/* Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
 */

#include "TouringTaskFactory.hpp"
#include "TaskFactoryConstraints.hpp"
#include "Task/Ordered/OrderedTaskBehaviour.hpp"
#include "Util/Macros.hpp"

static constexpr TaskFactoryConstraints touring_constraints = {
  false,
  false,
  true,
  false,
  false,
  2, 10,
};

static constexpr LegalPointSet touring_start_types{
  TaskPointFactoryType::START_CYLINDER,
};

static constexpr LegalPointSet touring_im_types{
  TaskPointFactoryType::FAI_SECTOR,
};

static constexpr LegalPointSet touring_finish_types{
  TaskPointFactoryType::FINISH_CYLINDER,
};

TouringTaskFactory::TouringTaskFactory(OrderedTask& _task,
                               const TaskBehaviour &tb)
  :AbstractTaskFactory(touring_constraints, _task, tb,
                       touring_start_types, touring_im_types,
                       touring_finish_types)
{
}

void 
TouringTaskFactory::UpdateOrderedTaskBehaviour(OrderedTaskBehaviour& to)
{
  AbstractTaskFactory::UpdateOrderedTaskBehaviour(to);

  to.aat_min_time = fixed(0);

  to.start_constraints.max_speed = fixed(0);
  to.start_constraints.max_height = 0;
  to.start_constraints.max_height_ref = AltitudeReference::AGL;
  to.finish_constraints.min_height = 0;
}
